@@ -9,8 +9,11 @@ class ApiManager():
         application.app_context().push()
         manager = Manager(application)
 
+        with application.app_context():
+            from .models import imports
+
         @manager.command
         def start():
             application.run(host="0.0.0.0")
         
-        manager.run()
+        manager.run()
\ No newline at end of file
